@@ -14,7 +14,7 @@ use warnings;
 use DBI;
 use Carp;
 
-our $VERSION = 0.91;
+our $VERSION = 0.95;
 
 sub new {
     my ($proto, %config) = @_;
@@ -98,6 +98,43 @@ declare multiple modules with different modnames).
 
 dburl is the DBI connection string, see DBD::Pg.
 
+=head2 AutoCommit
+
+Get/Set the DBD::Pg "AutoCommit" setting
+
+=head2 RaiseError
+
+Get/Set the DBD::Pg "RaiseError" setting
+
+=head2 errstr
+
+Get the DBI errorstring.
+
+=head2 do
+
+Execute a DBI statement with "do"
+
+=head2 prepare
+
+Prepare a (non-cached) Statement.
+
+=head2 prepare_cached
+
+Prepare a server cached statement (may fall back to non-cached transparently, see DBD::Pg and PostgreSQL documentation
+for details).
+
+=head2 quote
+
+Quote a variable for use in PostgreSQL statements.
+
+=head2 commit
+
+Commit transaction.
+
+=head2 rollback
+
+Rollback transaction.
+
 =head1 Dependencies
 
 This module is a basic module which does not depend on other worker modules.
